; /////////////////////////////////////////////////////////////////////////////////
;//                                                                               //
;//  This program and its associated documentation are provided for your personal //
;//  use only and appear here exclusively by permission of the copyright holder.  //
;//  Please contact the copyright holder before re-distributing, re-publishing    //
;//  or disseminating this copyrighted work. This code is not GPL or in the       // 
;//  public domain. Please respect the author's copyright.                        //
;//                                                                               //
;//  No waranty, either expressed or implied, are given.  I assume no liability   //
;//  for its use in any project or device.                                        //
;//                                                                               //
;//  Your use of this program indicates your acceptance of all license terms.     //
;//  This particular version is freeware as long as the copyright messages are    //
;//  left intact.                                                                 //  
;//                                                                               //
; /////////////////////////////////////////////////////////////////////////////////
;
; TASS Assembler v1.31
; 65816 instructions implimented via macro's
;
; By Daryl Rictor   1-14-2008
;
; assembly line format examples:
;[label] #LDA_ALX $C000, $00
;        #PLB
;        #REP $30
;

PLB		.macro
		.byte  $AB         ; PLB - pull DBR from stack - 1 byte instruction
.endm

PHB		.macro
		.byte  $8B         ; PHB - push DBR to stack - 1 byte instruction
.endm

PLD		.macro
		.byte  $2B         ; PLB - pull DBR from stack - 1 byte instruction
.endm

PHD		.macro
		.byte  $0B         ; PHB - push DBR to stack - 1 byte instruction
.endm

PEA		.macro
		.byte  $F4         ; PEA - push abs value to stack - 3 byte instruction
		.word  \1          ; low word
.endm


XCE		.macro
		.byte  $FB         ; XCE - set Emulation/Native mode - 1 byte instruction
.endm

LDA_ALX		.macro
		.byte  $BF         ; LDA_ALX - LDA al,x  absolute long addressing - 4 byte instruction
		.word  \1          ; low word
		.byte  \2          ; upper address byte 
.endm

LDA_DIIL	.macro
		.byte  $B7         ; LDA_DIIL - LDA [d],y direct indirect indexed long addressing - 2 byte instruction
		.byte  \1          ; index address byte 
.endm

LDA_AL		.macro
		.byte  $AF         ; LDA_AL - LDA al absolute long addressing - 4 byte instruction
		.word  \1          ; low word
		.byte  \2          ; upper address byte 
.endm

STA_AL		.macro
		.byte  $8F         ; STA_AL - STA al absolute long addressing - 4 byte instruction
		.word  \1          ; low word
		.byte  \2          ; upper address byte 
.endm

STA_ALX		.macro
		.byte  $9F         ; STA_ALX - STA al absolute long indexed X addressing - 4 byte instruction
		.word  \1          ; low word
		.byte  \2          ; upper address byte 
.endm

REP		.macro
		.byte  $C2         ; REP - reset Status register bits - 2 byte immediate addressing
		.byte  \1          ; mask value
.endm

SEP		.macro
		.byte  $E2         ; SEP - Set Status register bits - 2 byte immediate addressing
		.byte  \1          ; mask value
.endm

LDAI16		.macro
		.byte  $A9         ; LDAI16 - LDA Immediate 16 bits
		.word  \1
.endm

LDXI16		.macro
		.byte  $A2         ; LDXI16 - LDA Immediate 16 bits
		.word  \1
.endm

LDYI16		.macro
		.byte  $A0         ; LDYI16 - LDA Immediate 16 bits
		.word  \1
.endm

MVN		.macro
		.byte  $54         ; MVN - block Move Negative
		.byte  \1          ; dest block
		.byte  \2          ; source block
.endm

MVP		.macro
		.byte  $44         ; MVP - block Move Positive
		.byte  \1          ; dest block
		.byte  \2          ; source block
.endm

XBA		.macro
		.byte  $EB         ; XBA - Swap B - A, implied addressing
.endm

TCS		.macro
		.byte  $1B         ; TCS - Mov C -> Stack Pointer, implied addressing
.endm

TDC		.macro
		.byte  $7B         ; TDC - Mov D -> C, implied addressing
.endm

TSC		.macro
		.byte  $3B         ; TSC - Mov S -> C, implied addressing
.endm

JML		.macro
		.byte  $DC         ; Jump Indirect Long
		.word  \1          ; address in bank 0 with 3 byte address to jump to
.endm

ADCI16		.macro
		.byte  $69         ; ADC immediate using 16 bit value
		.word  \1          ; 16 bit value
.endm

CMP_AL		.macro
		.byte  $CF         ; CMP absolute Long
		.word  \1          ; low word
		.byte  \2          ; upper address byte 
.endm
